package svc

import (
	commonConfig "cicv-data-closedloop/pji/common/cfg"
	"cicv-data-closedloop/pji/common/global"
	"cicv-data-closedloop/pji/common/log"
	commonService "cicv-data-closedloop/pji/common/svc"
	util2 "cicv-data-closedloop/pji/common/util"
	"time"
)

// RunTimeWindowProducerQueue 将时间窗口内的包全部move出去，并等待当前时间窗口结束触发上传
func RunTimeWindowProducerQueue() {
	log.GlobalLogger.Info("生产者队列goroutine - 启动")
	for {
		// 收到自杀信号
		signal := <-commonService.ChannelKillMove
		if signal == 1 {
			commonService.ChannelKillMove <- 1
			if len(global.TimeWindowProducerQueue) == 0 {
				commonService.AddKillTimes("4")
				return
			}
		} else { //signal == 2
			commonService.AddKillTimes("4")
			return
		}

		// 处理
		time.Sleep(time.Duration(1) * time.Second)
		if len(global.TimeWindowProducerQueue) > 0 {
			bags := util2.ListAbsolutePathWithSuffixAndSort(commonConfig.CloudConfig.BagDataDir, ".bag")
			currentTimeWindow := global.TimeWindowProducerQueue[0]
			move := false
			bigger := false
			for _, bag := range bags {
				bagTime := util2.GetBagTime(bag)
				// 2 如果bag不小于timeWindowBegin不大于timeWindowEnd，则移动
				compare1 := util2.TimeCustom1GreaterEqualThanTimeCustom2(bagTime, currentTimeWindow.TimeWindowBegin)
				compare2 := util2.TimeCustom1LessEqualThanTimeCustom2(bagTime, currentTimeWindow.TimeWindowEnd)
				if compare1 && compare2 {
					// 将bag包移动到Copy目录
					util2.MoveFromDataToCopy(currentTimeWindow.FaultTime, bag)
					move = true
				} else {
					if util2.TimeCustom1GreaterEqualThanTimeCustom2(bagTime, currentTimeWindow.TimeWindowBegin) {
						// 必须已经生成了窗口之后的包才算窗口结束了
						bigger = true
						break
					}
				}
			}
			// 如果没有包可以供当前窗口移动，且已经生成了更新的包，则当前窗口已经可以上传
			if !move && bigger {
				util2.SupplyCopyBags(currentTimeWindow)
				// 将时间窗口移出准备队列
				util2.RemoveHeaOfdTimeWindowProducerQueue()
				// 将时间窗口加入运行队列
				util2.AddTimeWindowToTimeWindowConsumerQueue(currentTimeWindow)
				continue
			}
		}
	}
}
